@@ -19,7 +19,7 @@ def MakePlots(df, cat_features, con_features):
 
     # Heat Map
     h, axs = plt.subplots()
-    sns.heatmap(df.corr())
+    sns.heatmap(df.corr(),annot=True,fmt='.2g')
     axs.set_title('HeatMap :- ')
     plt.savefig("HeatMap.pdf")
 
@@ -42,7 +42,7 @@ def MakePlots(df, cat_features, con_features):
             if column < 3:
                 try:
                     axes[row, column].set_title('DistPlot :- ' + i)
-                    sns.distplot(df[i], ax=axes[row, column])
+                    sns.distplot(df[i].dropna(), ax=axes[row, column])
                     column += 1
                     if column == 3:
                         row += 1
@@ -65,7 +65,7 @@ def MakePlots(df, cat_features, con_features):
             if column < 3:
                 try:
                     axes[row, column].set_title('CountPlot :- ' + i)
-                    sns.countplot(df[i], ax=axes[row, column])
+                    sns.countplot(df[i].dropna(), ax=axes[row, column])
                     column += 1
                     if column == 3:
                         row += 1
@@ -89,7 +89,7 @@ def MakePlots(df, cat_features, con_features):
                 if column < 3:
                     try:
                         axes[row, column].set_title('BarPlot :- ' + i + ' Vs ' + j)
-                        sns.barplot(x=i, y=j, data=df, ax=axes[row, column])
+                        sns.barplot(x=i, y=j, data=df.dropna(), ax=axes[row, column])
                         column += 1
                         if column == 3:
                             row += 1
@@ -113,7 +113,7 @@ def MakePlots(df, cat_features, con_features):
                 if column < 3:
                     try:
                         axes[row, column].set_title('BoxPlot :- ' + j + ' Vs ' + i)
-                        sns.boxplot(x=j, y=i, data=df, ax=axes[row, column])
+                        sns.boxplot(x=j, y=i, data=df.dropna(), ax=axes[row, column])
                         column += 1
                         if column == 3:
                             row += 1
@@ -137,7 +137,7 @@ def MakePlots(df, cat_features, con_features):
                 if column < 3:
                     try:
                         axes[row, column].set_title('ViolinPlot :- ' + i + ' Vs ' + j)
-                        sns.violinplot(x=i, y=j, data=df, ax=axes[row, column])
+                        sns.violinplot(x=i, y=j, data=df.dropna(), ax=axes[row, column])
                         column += 1
                         if column == 3:
                             row += 1
@@ -148,15 +148,19 @@ def MakePlots(df, cat_features, con_features):
     plt.savefig("ViolinPlots.pdf")
     plt.tight_layout()
 
+
     # Pair Plot
     a = sns.pairplot(df)
     a.fig.suptitle('PairPlot :- ')
     plt.savefig("PairPlot.pdf")
 
     for i in cat_features:
-        a = sns.pairplot(df, hue=i)
-        a.fig.suptitle("PairPlot :- " + i)
-        plt.savefig("PairPlot%s.pdf" % i)
+        try:
+            a = sns.pairplot(df, hue=i)
+            a.fig.suptitle("PairPlot :- " + i)
+            plt.savefig("PairPlot%s.pdf" % i)
+        except:
+            continue
 
     CurrentDirectory = os.getcwd()
     AllFiles = os.listdir(CurrentDirectory)
