@@ -51,8 +51,7 @@ class build:
         
         Regression Algorithms :
         LinearRegression, PolynomialRegression, RidgeRegression,
-        LassoRegression, SupportVectorRegressor, GradientBoostingRegression, 
-        PLSRegression.
+        LassoRegression, SupportVectorRegressor, GradientBoostingRegression.
         """
         try:
             if(self.model.lower()=='classification'):
@@ -99,7 +98,7 @@ class build:
 
             elif(self.model.lower()=='regression'):
 
-                algorithms = ["LinearRegression","PolynomialRegression","RidgeRegression","LassoRegression","SupportVectorRegressor","GradientBoostingRegression","PLSRegression"]
+                algorithms = ["LinearRegression","PolynomialRegression","RidgeRegression","LassoRegression","SupportVectorRegressor","GradientBoostingRegression"]
 
                 LinearReg = BuildRegression.LinearReg(self.x_train,self.x_test,self.y_train,self.y_test)
                 PolynomialRegression = BuildRegression.PolynomialRegression(self.x_train,self.x_test,self.y_train,self.y_test)
@@ -107,16 +106,16 @@ class build:
                 LassoRegression = BuildRegression.LassoRegression(self.x_train,self.x_test,self.y_train,self.y_test)
                 SupportVectorRegressor = BuildRegression.SupportVectorRegressor(self.x_train,self.x_test,self.y_train,self.y_test)
                 GradientBoostingRegression = BuildRegression.GradientBoostingRegression(self.x_train,self.x_test,self.y_train,self.y_test)
-                PartialLeastSquares = BuildRegression.PartialLeastSquares(self.x_train,self.x_test,self.y_train,self.y_test)
+                #PartialLeastSquares = BuildRegression.PartialLeastSquares(self.x_train,self.x_test,self.y_train,self.y_test)
 
-                functions = [LinearReg,PolynomialRegression,RidgeRegression,LassoRegression,SupportVectorRegressor,GradientBoostingRegression,PartialLeastSquares]
+                functions = [LinearReg,PolynomialRegression,RidgeRegression,LassoRegression,SupportVectorRegressor,GradientBoostingRegression]
 
 
-                R2Score = [functions[algorithm][0] for algorithm in range(7)]
-                AdjustedR2 = [functions[algorithm][1] for algorithm in range(7)]
-                MeanAbsoluteError = [functions[algorithm][2] for algorithm in range(7)]
-                MeanSquaredError = [functions[algorithm][3] for algorithm in range(7)]
-                RootMeanSquaredError = [functions[algorithm][4] for algorithm in range(7)]
+                R2Score = [functions[algorithm][0] for algorithm in range(6)]
+                AdjustedR2 = [functions[algorithm][1] for algorithm in range(6)]
+                MeanAbsoluteError = [functions[algorithm][2] for algorithm in range(6)]
+                MeanSquaredError = [functions[algorithm][3] for algorithm in range(6)]
+                RootMeanSquaredError = [functions[algorithm][4] for algorithm in range(6)]
 
 
                 df = {"1-R2Score":R2Score,"1-AdjustedR2":AdjustedR2,"MeanAbsoluteError":MeanAbsoluteError,
